@@ -273,7 +273,7 @@ class I2AChatApiClient:
             :param is_active: bool
             :return: response - 200
         """
-        url = self._get_full_url(f'server-to-server/v1/chat-message/{message_timestamp_identifier}/set-active/')
+        url = self._get_full_url(f'chat-message/{message_timestamp_identifier}/set-active/')
         data = {
             'is_active': is_active
         }
